{-|
Module      : CLI.Notifications
Description : Gargantext Notifications CLI
Copyright   : (c) CNRS, 2017-Present
License     : AGPL + CECILL v3
Maintainer  : team@gargantext.org
Stability   : experimental
Portability : POSIX

-}


module CLI.Notifications where

import CLI.Parsers (settings_p)
import CLI.Types
import Data.ByteString.Lazy qualified as BSL
import Data.List qualified as List (cycle, concat, take)
import Data.Text.Encoding qualified as TE
import Gargantext.Core.Config.Utils (readConfig)
import Gargantext.Core.Notifications.CentralExchange qualified as CE
import Gargantext.Prelude
import Options.Applicative
import Prelude qualified



notificationsCLI :: CLINotification -> IO ()
notificationsCLI (CLIN_send (NotificationsArgs { .. })) = do
  let ___ = putStrLn ((List.concat
                       $ List.take 72
                       $ List.cycle ["_"]) :: Prelude.String)

  ___

  putText $ "notification: " <> n_message

  cfg <- readConfig n_toml
  CE.notifyRaw cfg $ BSL.fromStrict $ TE.encodeUtf8 n_message
  
  pure ()
  

notificationsCmd :: HasCallStack => Mod CommandFields CLI
notificationsCmd = command "notifications" (info (helper <*> (fmap CLISub $ fmap CCMD_notifications notificationsParser))
                               (progDesc "Gargantext notifications."))

notificationsParser :: Parser CLINotification
notificationsParser = hsubparser (
  command "send" (info (helper <*> send_p)
                  (progDesc "Send notification"))
  )

send_p :: Parser CLINotification
send_p = fmap CLIN_send $ NotificationsArgs
  <$> settings_p
  <*> strOption ( long "notification"
                  <> metavar "STRING"
                  <> help "Notification"
                  <> value "{\"type\": \"ping\"}" )

